#! /bin/bash
#
# xdtv_record.sh
#  
# Made by (Cyriac BENOIT)
# Login   <cyriac@free-unices.org>
#
# Started on  Mon Sep 22 01:03:19 2003 Cyriac BENOIT
# Last update Wed Jan 16 11:08:32 2004 Cyriac BENOIT
#
## Update 21/03/2006 Nico (estre@users.sourceforge.net)
#  correct bug signaled by 'fgrn' : script cannot handled 08 or 09 because the value is too great in octal base
#
# Update 02/07/2005 Nico (estre@users.sourceforge.net)
# internationalization support added
#
# Update 09/06/2005 Petr Jakubec (jakubec03@users.sourceforge.net) PATCH n 1245460
# 1. correction choises shutdown [N/y].
# 2. correction shutdown for Mandrake distributions
#
# Update 01/22/2006 Diego Ercolani (Diego.Ercolani@yacme.com) PATCH n 1411422
# More informations low in the script
#
# Update 02/05/2006  hg_rist (hg_rist@users.sourceforge.net) PATCH n 1424661
# xdtv_record.sh doesn't handle channel names containing blanks or slashes correctly.
#
# Update 02/06/2006 Diego Ercolani (Diego.Ercolani@yacme.com)
# fix the -q switch
#

export TEXTDOMAINDIR=/usr/share/locale
export TEXTDOMAIN=xdtv

function eko() {
	local let num=1
	local list_args=""
	local ori_par=""
	local trans_par=""
	local nopt=0
	while [[ $num -le $# ]] ; do
		eval ori_par="$`echo $num`"
		if [[ "$ori_par" != "-n" ]] ; then 
			if [[ $(which gettext) ]] ; then
				trans_par=`gettext "$ori_par"`
			else
				trans_par="$ori_par"
			fi
		else 
			nopt=1
		fi
		list_args="$list_args$trans_par"
		let num=$num+1

	done
	if [[ $nopt -eq 1 ]] ; then 
		echo -n $list_args
	else
		echo $list_args
	fi
}


# The only parameters to be configured...
config_file="${HOME}/.xdtv/xdtvrc"
config_dir="${HOME}/.xdtv/records"

# You shouldn't edit no further
VERSION="0.0.27"
channel=""
start_time=""
end_time=""
avi_title="default"
channel_number=""
divx_path=$(grep divx_path ${HOME}/.xdtv/xdtvrc | cut -d ' ' -f 3)
avi_dir="HOME"
others=""
expert="OFF"
quick="OFF"
shutdown="OFF"
cron="OFF"
edit=${EDITOR}

if [ ! -d ${HOME}/.xdtv ]; then
  eko "You must run and configure xdtv first!"
  exit 1
fi

if [ ! -d $config_dir ]; then
  mkdir $config_dir
fi



# Checking for needed binaries
binaries="grep crontab ls wc awk cut basename cat sed amixer killall xdtv sleep mv sudo /sbin/shutdown at chmod /usr/X11R6/xauth xargs ps head find"
for bin in $binaries; do
  $(which $bin 1>/dev/null 2>&1)
  if [ "$?" -eq 1 ]; then
    eko "$bin" " not found in \$PATH. This script may not work..."
  fi
done

if [ $(bash --version | grep version | sed -e 's/.*version \(.\).*/\1/') -lt 2 ]; then
  eko "You must have bash 2 in order to run this script."
  exit 1
fi

if [ -z "$edit" ]; then
  edit=$(which vi)
  if [ -z "$edit" ]; then
    edit=":"
    eko "No \$EDITOR found and vi not present."
    eko "Press Enter" "."
    read
  fi
fi

# Helper function
usage () {
  eko "Syntax: " "$(basename $0)" " [-c channel] [-d date ] [-s start time]"
  eko "        [-e end time] [-D avi directory] [-t avi title] [-x | --expert]"
  eko "        [-q | --quick] [-v | --version] [-S | --shutdown] [-h | --help]"
  echo ""
  eko "        Dates are in DD.MM.YY format and times are in HH:MM format."
  echo ""
  eko "        -x will enable \"expert mode\", asking more advanced parameters."
  eko "        In expert mode, you can schedule periodical records."
  echo ""
  eko "        -q will enable \"quick mode\", asking only date, times and channel"
  eko "           (if not given on command line)."
  echo ""
  exit 1
}

# Time functions
get_time () {

  # We modify IFS in order to split user input on ':'
#  oldifs="$IFS"
#  IFS=$':\n'

  if [[ $1 == "start" ]] ; then    ## necessaire pour la traduc. 
  	eko "-n" "Enter start time (HH:MM): "
  else 
  	if [[ $1 == "end" ]] ; then
  		eko "-n" "Enter end time (HH:MM): "
	else 
	  	eko "-n" "Enter " $1 " time (HH:MM): "
	fi
  fi

  read tmp_hour_minute
  tmp_hour=`echo $tmp_hour_minute | awk -F ":" '{print $1}'`
  tmp_minute=`echo $tmp_hour_minute | awk -F ":" '{print $2}'`
  
  # Error checking
  check_hour=$(echo -n "$tmp_hour" | wc -c)
  check_minute=$(echo -n "$tmp_minute" | wc -c)

  if [ $check_hour -ne 2 -o $check_minute -ne 2 ]; then
    eko "Wrong format. Must be HH:MM"
    IFS="$oldifs"
    get_time $1 $2
  fi

  IFS="$oldifs"

  # Setting variable
  eval "$2=$tmp_hour:$tmp_minute"
  
}
function oct_to_dec () {
	if [[ $1 = "08" ]] ; then
		echo 8
	else if [[ $1 = "09" ]] ; then
			echo 9
		else
			echo $1
		fi
	fi
}

get_recording_time () {
  start_hour=${1::2}
  start_minute=${1:3}
  stop_hour=${2::2}
  stop_minute=${2:3}

  start_hour=`oct_to_dec $start_hour`
  start_minute=`oct_to_dec $start_minute`
  stop_hour=`oct_to_dec $stop_hour`
  stop_minute=`oct_to_dec $stop_minute`

  if [ $start_hour -lt 10 ]; then
    start_hour=$(echo $start_hour | tr -d '0')
  fi
  if [ $stop_hour -lt 10 ]; then
    stop_hour=$(echo $stop_hour | tr -d '0')
  fi

  start=$((start_hour * 60 + start_minute))
  stop=$((stop_hour * 60 + stop_minute))

  # Adding a whole day for special cases (23:30 - 01:15)
  if [ $stop -lt $start ]; then
    stop=$((stop + 24 * 60))
  fi

  record_time=$((stop-start))
  if [ $record_time -lt 0 ]; then
    eko "Recording time would be " "$record_time" " minutes!"
    eko "There must be an error here. Exiting..."
    exit 1
  fi

  eko "Recording time will be:" " $record_time " "minutes"
  record_time=$((record_time * 60))
}

# Channel functions
get_channel () {

  # Parsing config file, looking for channel names ([name]) and stripping
  # square brackets
  channames=$(grep "^\[" $config_file | tr -d "\[\]")

  # Setting PS3 prompt (for select) and IFS as newline
  PS3=`eko "Select channel: "`
  oldifs="$IFS"
  IFS=$'\n'
  select channel in $channames; do
    echo $channel
    break
  done
  channel_number=$((REPLY - 1))

  # Restoring IFS
  IFS="$oldifs"
}

get_channel_name () {
  channel=$1
  grep "^\[" $config_file | awk 'NR == '$channel' { print }' | tr -d "\[\]"
}

# Menu functions

# Delete
delete_job () {
  eko "-n" "Do you want to delete recording job" " $1 " "? [N/y] "
  read answer

  if [ "$answer" = "y" -o "$answer" = "Y" ]; then
    echo $job_to_delete | grep "-" >/dev/null 2>&1
    check=$?
    if [ $check -eq 1 ]; then
      # At job
      # Removing script file
      script=$(grep -H "###JOB### $job_to_delete" $config_dir/2* | cut -d':' -f1)
      rm -f $script

      # Call to atrm
      atrm $1
    else
      script="$config_dir/cronjob_$job_to_delete"
      rm -f $script

      # Canceling job
      (crontab -l | grep -v "uniq_record: $job_to_delete" | crontab -)
    fi
    
    eko "Job deleted." " " "Press Enter" "..."
    read
  fi
}

# List
list_records () {
  clear
  if [ $(ls $config_dir/2* 2>/dev/null | wc -l) -ne 0 ]; then

    # We get all informations from script files
    for script in $config_dir/2*; do
      infos=$(grep "###INFOS###" $script)
      date=$(echo $infos | awk '{ print $2 }')
      year=$(echo $date | cut -c 1-4)
      month=$(echo $date | cut -c 5-6)
      day=$(echo $date | cut -c 7-8)
      date="${day}.${month}.${year}"
      channel=$(echo $infos | awk '{ print $3 }')
      channel=$(get_channel_name $((channel + 1)))
      time=$(echo $infos | awk '{ print $4 }')
      job=$(grep "###JOB###" $script | awk '{ print $2 }')
      eko "$job) $date" " on " "$channel" " at " "$time"
    done
  else

    # Or not
    eko "No records scheduled."
  fi
  echo ""
  eko "-n" "$@"
  read job_to_delete
  channel=""
  return $job_to_delete
}

list_cron_records () {
  clear
  if [ $(ls $config_dir/cronjob_* 2>/dev/null | wc -l) -ne 0 ]; then
    i=1
    
    # We get all informations from script files
    for script in $config_dir/cronjob_*; do
      infos=$(grep "###CRONJOB###" $script | cut -d' ' -f2-)
      jobid=$(grep "###JOB###" $script | cut -d' ' -f2)
      echo "$i) $infos - Id: $jobid"
      i=$((i + 1))
    done
  else

    # Or not
    eko "No records scheduled."
  fi
  echo ""

  eko "-n" "$@"
  read job
  jobs=($(ls $config_dir/cronjob_* 2>/dev/null))
  job_to_delete=$(echo ${jobs[$job - 1]} | cut -d'_' -f2)
}

# Create xdtv parameters line
make_command_line () {

  # Forcing grabdisplay in order to record something: not needed now!
  parameters=""
  
  if [ -n "$codec" ]; then
    parameters="${parameters} -rec_vcodec $codec"
  fi

  if [ -n "$size" ]; then
    parameters="${parameters} -rec_width $width -rec_height $height"
  fi

  if [ -n "$sub" ]; then
    parameters="${parameters} -rec_sub 1 -novbi"
  fi

  if [ -n "$quality" ]; then
    parameters="${parameters} -rec_mp3vbr $quality"
  fi

  if [ -n "$bitrate" ]; then
    parameters="${parameters} -rec_mp3cbr $bitrate"
  fi

  if [ -n "$nbufs" ]; then
    parameters="${parameters} -nbufs $nbufs"
  fi

  if [ -n "$others" ]; then
    parameters="${parameters} $others"
  fi
}

# Options parsing
while getopts ":c:s:e:d:D:t:qhvxS-:" option; do
  if [ "$option" = "-" ]; then
    case $OPTARG in
      help) option=h ;;
      quick) option=q ;;
      expert) option=x ;;
      version) option=v ;;
      shutdown) option=S ;;
    esac
  fi
  case $option in
    c) channel=$OPTARG ;;
    s) start_time=$OPTARG ;;
    e) end_time=$OPTARG ;;
    d) rec_date=$OPTARG ;;
    D) avi_dir=$OPTARG ;;
    t) avi_title=$OPTARG ;;
    x) expert="ON" ;;
    q) quick="ON" ;;
    S) shutdown="ON" ;;
    h) usage ;;
    v) eko "$(basename $0)" " version " "$VERSION"
       exit 0
       ;;
    :) eko "Missing argument for option" " -$OPTARG"
       usage ;;
    ?) eko "Unknown option" " -$OPTARG"
       usage ;;
  esac
done

# Main menu
while [ 1 -a "$quick" = "OFF" ]; do
  clear
  eko "1) Schedule a record"
  eko "2) Schedule a record in expert mode"
  eko "3) List scheduled records"
  eko "4) Delete a recording job"
  eko "5) Edit/view job"
  eko "6) Quit"
  echo ""


  eko "-n" " Enter your choice: [1] "
  read choice

  case "$choice" in
    2) expert="ON"
       clear
       break ;;
    3) clear
       eko "1) List regular jobs"
       eko "2) List periodical records (cron)"
       echo ""
       eko "-n" " Enter your choice: [1] "
       read choice

       if [ $choice -eq 2 ]; then
        list_cron_records "Press Enter" "..."
       else
         list_records "Press Enter" "..."
       fi ;;
    4) clear
       eko "1) Delete regular jobs"
       eko "2) Delete periodical records (cron)"
       echo ""
       eko "-n" " Enter your choice: [1] "
       read choice



       if [ $choice -eq 2 ]; then
         list_cron_records "Enter job to delete: "
       else
        list_records "Enter job to delete: "
       fi
       if [ -n "$job_to_delete" ]; then
         delete_job $job_to_delete
       fi
       ;;
    5) clear
       eko "1) Edit regular job"
       eko "2) Edit periodical records (cron)"
       echo ""
       eko "-n" " Enter your choice: [1] "
       read choice

       if [ $choice -eq 2 ]; then
         list_cron_records "Enter job to edit: "
       else
         list_records "Enter job to edit: "
       fi
       if [ -n "$job_to_delete" ]; then
         if [ $choice -eq 2 ]; then
           $edit $config_dir/cronjob_$job_to_delete
         else
           script=$(grep -H "###JOB### $job_to_delete" $config_dir/2* | cut -d':' -f1)
           $edit $script
         fi
       fi
       ;;
    6) exit 0 ;;
    *) clear; break ;;
  esac
done

# In expert mode we can make a cron job
if [ "$expert" = "ON" ]; then
  eko "1) Schedule a record (one time - at)"
  eko "2) Schedule a periodical record (cron)"
  echo ""

  eko "-n" " Enter your choice: [1] "
  read choice


  if [ $choice -eq 2 ]; then
    cron="ON"
  fi
fi

clear

if [ "$cron" = "OFF" ]; then
  # Getting day
  if [ -z "$rec_date" ]; then
    eko "-n" "Enter recording date (DD.MM.YY):" " [$(date +"%d.%m.%y")] "
    read rec_date
    if [ -z "$rec_date" ]; then
      rec_date=$(date +"%d.%m.%y")
    fi
  fi
else
  # Getting cron time specification
  
#eko  "We use the usual cron terminology.\n
#So, an '*' mean 'every', as in 'every minute, every hour, every month, every
#day and every day of the week' ('*' '*' '*' '*' '*').
#You can also specify ranges (2-8 = from the second to the eigth day of the
#month) and specific days as 1,3,5,28.

#Finally, you can mix everything:
#  '*'/2 0-9,12,16,18,20-23 '*' '*' '*' /usr/local/script

#  script will run every two minutes, from midnight to nine, at 12, 16, 18 and from 
#  twenty to eleven, every day, every month and every day of the week.

#You should really look at crontab(5) man page if you don't know what we're
#talking about."

eko "We use the usual cron terminology."
eko "So, an '*' mean 'every', as in 'every minute, every hour, every month, every"
eko "-n" "day and every day of the week'" 
echo "(* * * * *)."
eko "You can also specify ranges (2-8 = from the second to the eigth day of the"
eko "month) and specific days as 1,3,5,28."
eko "Finally, you can mix everything:"
echo "   */2 0-9,12,16,18,20-23 * * * /usr/local/script"

eko  "script will run every two minutes, from midnight to nine, at 12, 16, 18 and from"
eko  "twenty to eleven, every day, every month and every day of the week."
echo
eko  "You should really look at crontab(5) man page if you don't know what we're"
eko  "talking about."

  eko "-n" "Enter day of month (1-31): [*] "
  read cron_month_day

  if [ -z "$cron_month_day" ]; then 
    cron_month_day="*"
  fi
  if [ "$cron_month_day" = "*" ]; then
    tmd=`eko "-n" " Every day "`
  else
    tmd=`eko "-n" " On" " $cron_month_day "`
  fi

  eko "-n" "Enter month (1-12): [*] "
  read cron_month

  if [ -z "$cron_month" ]; then
    cron_month="*"
  fi
  if [ "$cron_month" = "*" ]; then
    tm=`eko "-n" " every month "`
  else
    tm="$cron_month "
  fi

  eko "-n" "Enter day of week (0-7, Sunday is either 0 or 7): [*] "
  read cron_week_day
  if [ -z "$cron_week_day" ]; then
    cron_week_day="*"
  fi
  if [ "$cron_week_day" = "*" ]; then
    twd=`eko "-n" " every day of the week"`
  else
    twd=`eko "-n" "the" " ${cron_week_day}" "th day of the week"`
  fi
  date="$tmd $tm $twd"
fi

# Getting missing hours
if [ -z "$start_time" ]; then
  get_time start start_time
fi

if [ -z "$end_time" ]; then
  get_time end end_time
fi

# Display total recording time
get_recording_time $start_time $end_time
echo ""

# Getting channel name and number
if [ -z "$channel" ]; then
  get_channel
else 
  channel_number=$((channel - 1))
  channel=$(get_channel_name $channel)
fi

# xdtv replaces '/' by '|' in channel names:
channel="${channel//\//|}"

echo ""

# Getting AVI directory
if [ "$avi_dir" = "HOME" -a "$quick" = "OFF" ]; then
  eko "-n" "Enter saving directory:" " [${divx_path:-$HOME}] "
  read avi_dir

fi

if [ ! -d "$avi_dir" -o -z "$avi_dir" -o "$avi_dir" = "HOME" ]; then
  avi_dir=${divx_path:-$HOME}
fi

if [ ! -d "$avi_dir" ]; then
  avi_dir=${HOME}
fi

# Getting AVI title

# keep the date in the filename (use ISO date format):
my_rec_date=$(echo $rec_date | sed -e 's/\(..\).\(..\).\(..\)/20\3-\2-\1/')
avi_title_default="${channel}_${my_rec_date}_${start_time}-${end_time}"

if [ "$avi_title" = "default" -a "$quick" = "OFF" ]; then
  eko "-n" "Enter movie title:" " [$avi_title_default] "
  read avi_title

  avi_title="${avi_title}"
fi

if [ "$avi_title" = "default" -o -z "$avi_title" ]; then
  avi_title="$avi_title_default"
fi

echo ""

# If we are in expert mode, we ask more questions
if [ "$expert" = "ON" ]; then

  # Getting codec - We do not verify that all codecs are supported !!
  codecs=(xvid divx4linux ffmpeg_mpeg1 ffmpeg_mpeg4)
  i=1
  for name in ${codecs[*]}; do
    echo "$i) $name"
    i=$((i + 1))
  done
  eko "-n" "Enter codec number: [1) xvid] "
  read codec_number


  if [ -z "$codec_number" ]; then
    codec="xvid"
  else
    codec=${codecs[$codec_number - 1]}
  fi

  echo ""

  # Getting resolution
  sizes=(384x288 480x360 576x432 768x576)
  i=1
  for size in ${sizes[*]}; do
    echo "$i) $size"
    i=$((i + 1))
  done
  eko "$i) ""Other"
  eko "-n" "Enter resolution: [1) 384x288] "
  read size


  if [ -z "$size" ]; then
    size="384x288"
  elif [ $size -eq $i ]; then
   eko "-n" "Enter your choice: "
   read size
  else
    size=${sizes[$size - 1]}
  fi
  
  # Get width and height from size
  width=${size/x*}
  height=${size/#*x}

  echo ""
  eko "-n" "Do you wanna record subtitles ? [N/y] "
  read sub

  echo ""
  eko "-n" "Modify sound parameters ? [N/y] "
  read answer
  if [ "$answer" = "y" -o "$answer" = "Y" ]; then
    eko "-n" "Constant or variable bitrate ? [C/v] "
    read answer
    if [ "$answer" = "v" -o "$answer" = "V" ]; then
      eko "-n" "Enter quality (0=best, 9=worst): [8] "
      read quality
      if [ -z "$quality" ]; then
        quality=8
      fi
    else
      eko "-n" "Enter bitrate (16-512): [128] "
      read bitrate
      if [ -z "$bitrate" ]; then
        bitrate=128
      fi
    fi
  fi

  echo ""
  eko "-n" "Enter number of kernel-buffered frames: [3] "
  read nbufs
  if [ -z "$nbufs" ]; then
    nbufs=3
  fi

  echo ""
  eko "-n" "Enter other options (for plugins for example): "
  read others

  echo ""
  eko "-n" "Do you wanna mute sound (for night recording) ? [Y/n] "
  read sound

# End of expert mode
fi

if [ "$shutdown" = "OFF" -a "$quick" = "OFF" ]; then
  eko "-n" "Do you wanna shut your computer down after recording ? [N/y] "
  read shutdown
  if [ -z "$shutdown" ] || [ "$shutdown" = "N" ] || [ "$shutdown" = "n" ]; then
    shutdown="OFF"
  fi
fi

make_command_line

if [ "$cron" = "OFF" ]; then
  date=$(echo $rec_date | sed -e 's/\(..\).\(..\).\(..\)/20\3\2\1/')
fi

if [ "$cron" = "OFF" ]; then
  file="$config_dir/${date}_${channel_number}_${start_time/:/}"
  echo "###INFOS### $date $channel_number $start_time" > $file
else
  # Hopefully unique...
  uniq="$$-$RANDOM$RANDOM$RANDOM"
  file="$config_dir/cronjob_$uniq"
  echo -e "#! /bin/bash\n" > $file
  echo "###CRONJOB### ${date} ${channel} ($start_time - $end_time)" >> $file
  echo -e "\nexport PATH=/bin:/usr/bin:/usr/local/bin" >> $file
  date=""
fi

# We need XdTV filename to rename it
#default_avi="movie-${channel// /\\ }-${date}-${start_time/:/}??-1.avi"

# Creating script
cat >> $file <<_END_
#
# Even if we have defined a DISPLAY, we can't detect easily its number.
# We could have more than one X server running on our machine,
# so it's better to fix it to the :0.0 or the :0 value.
# There is a chance that the first X invoked is running on the :0.0 display.
#
# We also suppose to run this script with root rights ;-(
# (probably not a good choice, but functional to gain the right to write to X screen)
#
# Now is time to determine what is the authority file generated by kdm, xdm or gdm:
#

XLINE=\$(ps axuwww | grep -e "[/\s]X .* \?-auth" | head -1)

AUTHORITYFILE=\$(echo \$XLINE | awk '/-auth/ { match( \$0, /.*-auth ([^ ]+).*/, pippo); print pippo[1]; }')
export DISPLAY=\$(echo \$XLINE | sed 's#.* \(:[0-9]\+\(\.\?[0-9]\+\)\?\).*#\1#' )

# If we launched X via a startx command, probably we have XAUTHORITY fixed
# in our home directory, so we use the \$XAUTHORITY value.

if [ -z "\$AUTHORITYFILE" ]; then
  AUTHORITYFILE=\$XAUTHORITY
fi

# Then we add the key found to our keyring
xauth -f \${AUTHORITYFILE:-\$HOME/.Xauthority} list | awk -v DISPLAY=\${DISPLAY:-:0} '{ print DISPLAY" "\$2" "\$3; }' | xargs xauth add

cd $avi_dir

default_avi="movie-${channel}-\$(date +%Y%m%d)-${start_time/:/}??-?.avi"

_END_

if [ -z "$sound" -o "$sound" = "y" -o "$sound" = "Y" ]; then
  echo "amixer set Master mute >/dev/null 2>&1" >> $file
fi

cat >> $file <<_END_
echo "Will kill all running xdtv !"
killall xdtv 2>/dev/null
xdtv $parameters -e "setstation $channel_number; record" &
sleep $record_time
xdtv_cmd "record; quit"
sleep 1
amixer set Line mute >/dev/null 2>&1

# Just to be sure...
killall xdtv 2>/dev/null

i=1

find . -name "\$default_avi" -print0 | while read -d $'\0' file
do
    mv "${divx_path:-$avi_dir}/\$file" "${avi_title}-\$i.avi"
    i=\$((i + 1))
done
_END_

if [ -z "$sound" -o "$sound" = "y" -o "$sound" = "Y" ]; then
  echo "amixer set Master unmute >/dev/null 2>&1" >> $file
fi

if [ "$cron" = "OFF" ]; then
  echo "rm -f $file" >> $file
fi

if [ "$shutdown" != "OFF" ]; then
  grep -E "Mandrake|Mandriva" /etc/redhat-release &>/dev/null && echo "halt" >> $file || echo "sudo shutdown -h now" >> $file
fi

# Scheduling
if [ "$cron" = "OFF" ]; then
  job=$(at -m -f $file $start_time $rec_date 2>&1 | grep job | cut -d' ' -f2)
  echo -e "\n###JOB### $job\n" >> $file
else
  (crontab -l; echo "$start_minute $start_hour $cron_month_day $cron_month $cron_week_day $file #uniq_record: $uniq") | crontab -
  echo -e "\n###JOB### $uniq\n" >> $file
  chmod +x $file
fi

# Display informations
eko "-n" "Will record" " $avi_title " "on channel" " $channel_number ($channel) " "from" " $start_time " "to" " $end_time " 
eko "-n" "in" " $avi_dir"

if [ "$cron" = "OFF" ]; then
  eko ", " "the" " $rec_date"
else
  echo ""
fi
eko "Script in" " $file"
echo ""

